@@ -1,4 +1,4 @@
-"""This is copy from pyXtal_FF. Contains atom features and bond features method."""
+"""This is copy from ``pyXtal_FF``. Contains atom features and bond features method."""
 
 __all__  =["ACSF", "behlerparrinello",
                         "EAD",
